@@ -14,6 +14,10 @@
 #include <QTime>
 #include <QFile>
 #include <QUrl>
+#ifndef NOAUDIO
+#include <QBuffer>
+#include <QAudioOutput>
+#endif
 
 #include "Environment.h"
 #include "StructEnumDefinition.h"
@@ -64,6 +68,7 @@ class Core : public QObject
             std::string collisionAction;
             std::string errorAction;
             bool isPaused;
+            bool havePause;
             bool isRunning;
             Ultracopier::CopyType type;
             Ultracopier::TransferListOperation transferListOperation;
@@ -129,6 +134,12 @@ class Core : public QObject
         LogThread log;///< To save the log like mkpath, rmpath, error, copy, ...
         uint64_t realByteTransfered;
 
+        #ifndef NOAUDIO
+        QBuffer buffer;
+        QAudioOutput *audio;
+        std::string soundFile;
+        #endif
+
         static uint8_t fileCatNumber(uint64_t size);
     signals:
         void copyFinished(const uint32_t & orderId,bool withError) const;
