@@ -4,68 +4,56 @@
 <context>
     <name>Themes</name>
     <message>
-        <location filename="../../interface.cpp" line="303"/>
-        <location filename="../../interface.cpp" line="320"/>
-        <source>%1 is deprecated, Use %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../interface.cpp" line="306"/>
-        <location filename="../../interface.cpp" line="323"/>
-        <source>This will be the last version for Mac, but you can compile from source</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../interface.cpp" line="325"/>
+        <location filename="../../interface.cpp" line="327"/>
         <source>Buy the Ultimate version to fund development</source>
         <translation>Comprar la versión Ultimate para financiar el desarrollo</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="410"/>
+        <location filename="../../interface.cpp" line="412"/>
         <source>File %1/%2, size: %3/%4</source>
         <translation>El archivo %1/%2, el tamaño: %3/%4</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="644"/>
+        <location filename="../../interface.cpp" line="646"/>
         <source>Copy list</source>
         <translation>Lista de copia</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="646"/>
+        <location filename="../../interface.cpp" line="648"/>
         <source>Move list</source>
         <translation>Lista de movimiento</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1067"/>
+        <location filename="../../interface.cpp" line="1076"/>
         <source>Don&apos;t close if errors are found</source>
         <translation>No cierre si se encuentran errores</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1068"/>
+        <location filename="../../interface.cpp" line="1077"/>
         <source>Never close</source>
         <translation>Nunca cierre</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1069"/>
+        <location filename="../../interface.cpp" line="1078"/>
         <source>Always close</source>
         <translation>Siempre cerrar</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1071"/>
+        <location filename="../../interface.cpp" line="1080"/>
         <source>File Name, 0KB</source>
         <translation>Nombre de archivo, 0KB</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1265"/>
-        <location filename="../../interface.cpp" line="1277"/>
-        <location filename="../../interface.cpp" line="1289"/>
+        <location filename="../../interface.cpp" line="1274"/>
+        <location filename="../../interface.cpp" line="1286"/>
+        <location filename="../../interface.cpp" line="1298"/>
         <source>Select a color</source>
         <translation>Seleccione un color</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1364"/>
-        <location filename="../../interface.cpp" line="1368"/>
-        <location filename="../../interface.cpp" line="1370"/>
+        <location filename="../../interface.cpp" line="1373"/>
+        <location filename="../../interface.cpp" line="1377"/>
+        <location filename="../../interface.cpp" line="1379"/>
         <source>%1 %2% of %3</source>
         <translation type="unfinished"></translation>
     </message>
