@@ -4,68 +4,56 @@
 <context>
     <name>Themes</name>
     <message>
-        <location filename="../../interface.cpp" line="303"/>
-        <location filename="../../interface.cpp" line="320"/>
-        <source>%1 is deprecated, Use %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../interface.cpp" line="306"/>
-        <location filename="../../interface.cpp" line="323"/>
-        <source>This will be the last version for Mac, but you can compile from source</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../interface.cpp" line="325"/>
+        <location filename="../../interface.cpp" line="327"/>
         <source>Buy the Ultimate version to fund development</source>
-        <translation>Acquista la versione Ultimate per finanziare lo sviluppo del programma</translation>
+        <translation>Acquista versione ultimate per finanziare lo sviluppo</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="410"/>
+        <location filename="../../interface.cpp" line="412"/>
         <source>File %1/%2, size: %3/%4</source>
         <translation>File %1/%2, dimensione: %3/%4</translation>
     </message>
-    <message>
-        <location filename="../../interface.cpp" line="644"/>
-        <source>Copy list</source>
-        <translation>Lista della copia</translation>
-    </message>
     <message>
         <location filename="../../interface.cpp" line="646"/>
+        <source>Copy list</source>
+        <translation>Lista di copia</translation>
+    </message>
+    <message>
+        <location filename="../../interface.cpp" line="648"/>
         <source>Move list</source>
-        <translation>Lista dello spostamento</translation>
+        <translation>Lista di spostamento</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1067"/>
+        <location filename="../../interface.cpp" line="1076"/>
         <source>Don&apos;t close if errors are found</source>
-        <translation>Non chiudere se vengono rilevati errori</translation>
+        <translation>Non chiudere se vengono trovati errori</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1068"/>
+        <location filename="../../interface.cpp" line="1077"/>
         <source>Never close</source>
         <translation>Non chiudere mai</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1069"/>
+        <location filename="../../interface.cpp" line="1078"/>
         <source>Always close</source>
         <translation>Chiudere sempre</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1071"/>
+        <location filename="../../interface.cpp" line="1080"/>
         <source>File Name, 0KB</source>
-        <translation>Nome del file, 0KB</translation>
+        <translation>Nome file, 0KB</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1265"/>
-        <location filename="../../interface.cpp" line="1277"/>
-        <location filename="../../interface.cpp" line="1289"/>
+        <location filename="../../interface.cpp" line="1274"/>
+        <location filename="../../interface.cpp" line="1286"/>
+        <location filename="../../interface.cpp" line="1298"/>
         <source>Select a color</source>
-        <translation>Scegliere un colore</translation>
+        <translation>Selezionare colore</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1364"/>
-        <location filename="../../interface.cpp" line="1368"/>
-        <location filename="../../interface.cpp" line="1370"/>
+        <location filename="../../interface.cpp" line="1373"/>
+        <location filename="../../interface.cpp" line="1377"/>
+        <location filename="../../interface.cpp" line="1379"/>
         <source>%1 %2% of %3</source>
         <translation>%1 %2% di %3</translation>
     </message>
@@ -92,7 +80,7 @@
         <location filename="../../ThemesFactory.cpp" line="497"/>
         <location filename="../../ThemesFactory.cpp" line="512"/>
         <source>Select a color</source>
-        <translation>Scegliere un colore</translation>
+        <translation>Selezionare colore</translation>
     </message>
 </context>
 <context>
@@ -105,72 +93,72 @@
     <message>
         <location filename="../../interface.ui" line="65"/>
         <source>To:</source>
-        <translation>a:</translation>
+        <translation>A:</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="226"/>
         <source>&amp;More</source>
-        <translation>Altr&amp;o</translation>
+        <translation>Avanzate</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="246"/>
         <source>&amp;Pause</source>
-        <translation>&amp;Pausa</translation>
+        <translation>Pausa</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="260"/>
         <source>&amp;Skip</source>
-        <translation>&amp;Salta</translation>
+        <translation>Salta</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="271"/>
         <source>&amp;Cancel</source>
-        <translation>&amp;Annulla</translation>
+        <translation>Annulla</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="118"/>
         <source>Close on transfer completion</source>
-        <translation>Arresta il sistema a trasferimento comletato</translation>
+        <translation>Chiudi a trasferimento completato</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="286"/>
         <source>Limit copy speed to:</source>
-        <translation>Limitare la velocità di copia a:</translation>
+        <translation>Limitare velocità di copia a:</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="329"/>
         <source>Transfer list</source>
-        <translation>Lista dei trasferimenti</translation>
+        <translation>Lista di trasferimento</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="352"/>
         <source>Move the selected items to the top</source>
-        <translation>Sposta in cima gli elementi selezionati</translation>
+        <translation>Metti elementi selezionati in cima</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="378"/>
         <source>Move up the selected items</source>
-        <translation>Sposta sopra gli elementi selezionati</translation>
+        <translation>Sposta elementi selezionati in sù</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="404"/>
         <source>Move down the selected items</source>
-        <translation>Sposta sotto gli elementi selezionati</translation>
+        <translation>Sposta elementi selezionati in giù</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="430"/>
         <source>Move the selected items to the bottom</source>
-        <translation>Sposta in coda gli elementi selezionati</translation>
+        <translation>Metti elementi selezionati in coda</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="456"/>
         <source>Add file/folder</source>
-        <translation>Aggiungi file/cartelle</translation>
+        <translation>Aggiungi file/cartella</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="485"/>
         <source>Delete the selected items</source>
-        <translation>Elimina gli elementi selezionati</translation>
+        <translation>Elimina elementi selezionati</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="511"/>
@@ -180,12 +168,12 @@
     <message>
         <location filename="../../interface.ui" line="540"/>
         <source>Export the transfer list</source>
-        <translation>Esporta la lista dei trasferimenti</translation>
+        <translation>Esporta lista di trasferimento</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="566"/>
         <source>Import the transfer list</source>
-        <translation>Importa la lista dei trasferimenti</translation>
+        <translation>Importa lista di trasferimento</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="621"/>
@@ -206,17 +194,17 @@
     <message>
         <location filename="../../interface.ui" line="683"/>
         <source>Export the errors into transfer list</source>
-        <translation>Esporta gli errori nella lista dei trasferimenti</translation>
+        <translation>Esporta errori in lista di trasferimento</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="722"/>
         <source>Source</source>
-        <translation>Cartella di origine</translation>
+        <translation>Origine</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="727"/>
         <source>Destination</source>
-        <translation>Cartella di destinazione</translation>
+        <translation>Destinazione</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="741"/>
@@ -236,22 +224,22 @@
     <message>
         <location filename="../../interface.ui" line="796"/>
         <source>Move file(s)</source>
-        <translation>Sposta file</translation>
+        <translation>Spostare file</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="805"/>
         <source>Move folder</source>
-        <translation>Sposta la cartella</translation>
+        <translation>Spostare cartella/e</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="814"/>
         <source>Copy file(s)</source>
-        <translation>Copia file</translation>
+        <translation>Copiare file</translation>
     </message>
     <message>
         <location filename="../../interface.ui" line="823"/>
         <source>Copy folder</source>
-        <translation>Copia la cartella</translation>
+        <translation>Copiare cartella/e</translation>
     </message>
 </context>
 <context>
@@ -259,48 +247,48 @@
     <message>
         <location filename="../../themesOptions.ui" line="267"/>
         <source>Show dual progression</source>
-        <translation>Mostrare la doppia progressione</translation>
+        <translation>Mostrare progressione duale</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="219"/>
         <source>Show speed as main information</source>
-        <translation>Mostrare la velocità come principale informazione</translation>
+        <translation>Mostrare velocità come informazione principale</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="44"/>
         <source>Use</source>
-        <translation>Utilità</translation>
+        <translation>Funzionalità</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="173"/>
         <source>Start with the &quot;more button&quot; pushed</source>
-        <translation>Iniziare col pulsante &quot;Altro&quot; attivo</translation>
+        <translation>Avvio con bottone &quot;Avanzate&quot; premuto</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="67"/>
         <source>Minimize on close to systray</source>
-        <translation>Alla chiusura riduci nella&apos;area di notifica</translation>
+        <translation>Alla chiusura riduci nell&apos;area di notifica</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="96"/>
         <source>At the end of the copy</source>
-        <translation>Al termine della copia</translation>
+        <translation>A fine copia</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="103"/>
         <location filename="../../themesOptions.ui" line="137"/>
         <source>Limit copy speed to</source>
-        <translation>Limitare la velocità di copia a</translation>
+        <translation>Limitare velocità di copia a</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="53"/>
         <source>Start minimized</source>
-        <translation type="unfinished"></translation>
+        <translation>Avvia ridotto a icona</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="306"/>
         <source>Click to edit the color</source>
-        <translation>Clicca per modificare il colore</translation>
+        <translation>Cliccare per modificare colore</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="147"/>
@@ -310,7 +298,7 @@
     <message>
         <location filename="../../themesOptions.ui" line="190"/>
         <source>Save position</source>
-        <translation type="unfinished"></translation>
+        <translation>Salva posizione</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="213"/>
@@ -320,22 +308,22 @@
     <message>
         <location filename="../../themesOptions.ui" line="251"/>
         <source>Display</source>
-        <translation>Visualizza</translation>
+        <translation>Visualizzazione</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="257"/>
         <source>Speed with progress bar</source>
-        <translation>Velocità nella barra di progresso</translation>
+        <translation>Velocità in barra progresso</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="287"/>
         <source>Progression color</source>
-        <translation>Colore della progressione</translation>
+        <translation>Colore progressione</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="277"/>
         <source>Show progression in the title</source>
-        <translation>Mostrare la percentuale di progresso sul titolo</translation>
+        <translation>Mostra percentuale di progresso nel titolo</translation>
     </message>
     <message>
         <location filename="../../themesOptions.ui" line="183"/>
